<?php

namespace Litecms\Planpackage\Policies;

use Litepie\User\Contracts\UserPolicy;
use Litecms\Planpackage\Models\Planpackage;

class PlanpackagePolicy
{

    /**
     * Determine if the given user can view the planpackage.
     *
     * @param UserPolicy $user
     * @param Planpackage $planpackage
     *
     * @return bool
     */
    public function view(UserPolicy $user, Planpackage $planpackage)
    {
        if ($user->canDo('planpackage.planpackage.view') && $user->isAdmin()) {
            return true;
        }

        return $planpackage->user_id == user_id() && $planpackage->user_type == user_type();
    }

    /**
     * Determine if the given user can create a planpackage.
     *
     * @param UserPolicy $user
     * @param Planpackage $planpackage
     *
     * @return bool
     */
    public function create(UserPolicy $user)
    {
        return  $user->canDo('planpackage.planpackage.create');
    }

    /**
     * Determine if the given user can update the given planpackage.
     *
     * @param UserPolicy $user
     * @param Planpackage $planpackage
     *
     * @return bool
     */
    public function update(UserPolicy $user, Planpackage $planpackage)
    {
        if ($user->canDo('planpackage.planpackage.edit') && $user->isAdmin()) {
            return true;
        }

        return $planpackage->user_id == user_id() && $planpackage->user_type == user_type();
    }

    /**
     * Determine if the given user can delete the given planpackage.
     *
     * @param UserPolicy $user
     * @param Planpackage $planpackage
     *
     * @return bool
     */
    public function destroy(UserPolicy $user, Planpackage $planpackage)
    {
        return $planpackage->user_id == user_id() && $planpackage->user_type == user_type();
    }

    /**
     * Determine if the given user can verify the given planpackage.
     *
     * @param UserPolicy $user
     * @param Planpackage $planpackage
     *
     * @return bool
     */
    public function verify(UserPolicy $user, Planpackage $planpackage)
    {
        if ($user->canDo('planpackage.planpackage.verify')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the given user can approve the given planpackage.
     *
     * @param UserPolicy $user
     * @param Planpackage $planpackage
     *
     * @return bool
     */
    public function approve(UserPolicy $user, Planpackage $planpackage)
    {
        if ($user->canDo('planpackage.planpackage.approve')) {
            return true;
        }

        return false;
    }

    /**
     * Determine if the user can perform a given action ve.
     *
     * @param [type] $user    [description]
     * @param [type] $ability [description]
     *
     * @return [type] [description]
     */
    public function before($user, $ability)
    {
        if ($user->isSuperuser()) {
            return true;
        }
    }
}
